@@ -38,7 +38,10 @@ sub meta_merge {
 	    directory	=> [ qw{ inc t xt } ],
 	},
 	resources	=> {
-	    bugtracker	=> 'https://rt.cpan.org/Public/Dist/Display.html?Name=Encode-RAD50',
+	    bugtracker	=> {
+		web	=> 'https://rt.cpan.org/Public/Dist/Display.html?Name=Encode-RAD50',
+                mailto  => 'wyant@cpan.org',
+            },
 	    license	=> 'http://dev.perl.org/licenses/',
 	    repository	=> {
 		type	=> 'git',
